==> fahrplan_0.0.15.tar.gz: fahrplan-0.0.15/fahrplan_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.cpp" line="31"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="36"/>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="41"/>
        <source>Toggle GPS</source>
        <translation>GPS An/Aus</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="46"/>
        <location filename="mainwindow.cpp" line="436"/>
        <source>Donate</source>
        <translation>Spenden</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="62"/>
        <source>Station from</source>
        <translation>Haltestelle ab</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="63"/>
        <source>Station to</source>
        <translation>Haltestelle bis</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="66"/>
        <location filename="mainwindow.cpp" line="68"/>
        <location filename="mainwindow.cpp" line="814"/>
        <source>please select</source>
        <translation>bitte wählen</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="92"/>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="96"/>
        <source>Time</source>
        <translation>Uhrzeit</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="111"/>
        <source>Arrival time</source>
        <translation>Ankunft</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="115"/>
        <source>Departure time</source>
        <translation>Abfahrt</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="119"/>
        <source>Use selected date/time as</source>
        <translation>Datum und Zeit verwenden als</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="127"/>
        <source>Restrict train types</source>
        <translation>Verkehrsmittel</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="138"/>
        <source>Search</source>
        <translation>Suchen</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="197"/>
        <source>Welcome to a new version of fahrplan this has changed</source>
        <translation>Willkommen bei einer neuen Version von Fahrplan, dies ist neu</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="198"/>
        <source>- bahn.de: adding train restrictions&lt;br&gt;- Calendar: you can select to which calendar you want add the journey.&lt;br&gt;- last used stationnames could be filled automatically on startup.&lt;br&gt;- Added a Donate link to the mainmenu</source>
        <translation>- bahn.de: filtern nach Verkehrsmittel&lt;br&gt;-Kalender: Man kann nun wählen zu welchem Kalender man die Verbindung hinzufügen möchte&lt;br&gt;-letzte Haltestelle kann automatisch gefüllt werden&lt;br&gt;Es gibt nun einen Spenden knopf</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="232"/>
        <source>not supported</source>
        <translation>nicht unterstützt</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="256"/>
        <source>&lt;br&gt;GPS is now available!&lt;br&gt;</source>
        <translation>&lt;br&gt;GPS ist nun verfügbar!&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="267"/>
        <source>&lt;br&gt;GPS is now &lt;b&gt;disabled&lt;/b&gt;&lt;br&gt;</source>
        <translation>&lt;br&gt;GPS ist jetzt &lt;b&gt;aus&lt;/b&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="272"/>
        <source>&lt;br&gt;GPS is now &lt;b&gt;enabled&lt;/b&gt;&lt;br&gt;</source>
        <translation>&lt;br&gt;GPS ist jetzt &lt;b&gt;an&lt;/b&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="307"/>
        <source>Journey: </source>
        <translation>Verbindung: </translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="307"/>
        <location filename="mainwindow.cpp" line="308"/>
        <location filename="mainwindow.cpp" line="578"/>
        <source> to </source>
        <translation> nach </translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="316"/>
        <source>Duration: </source>
        <translation>Dauer: </translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="353"/>
        <source>

(added by fahrplan app, please recheck informations before travel.)</source>
        <translatorcomment>dont use umlauts!</translatorcomment>
        <translation>

(hinzugefuegt von Fahrplan, bitte vor Fahrantritt daten erneut pruefen)</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="363"/>
        <source>&lt;br&gt;Entry is in the past!&lt;br&gt;</source>
        <translation>&lt;br&gt;Eintrag ist in der Vergangenheit!&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="377"/>
        <source>&lt;br&gt;Entry added to the </source>
        <translation>&lt;br&gt;Eintrag wurde zum </translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="377"/>
        <source> calendar.&lt;br&gt;</source>
        <translation> Kalender hinzugefügt.&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="403"/>
        <source>Select target calendar</source>
        <translation>Ziel Kalender wählen</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="437"/>
        <source>Thank you for Donating!</source>
        <translation>Danke fürs spenden!</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="443"/>
        <source>by smurfy (maemo@smurfy.de)&lt;br&gt;Version </source>
        <translation>von smurfy (maemo@smurfy.de)&lt;br&gt;Version </translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="443"/>
        <source>&lt;br&gt;&lt;br&gt;Current supported databackends:&lt;br&gt;&lt;b&gt;bahn.de&lt;/b&gt;, &lt;b&gt;mvv-muenchen.de&lt;/b&gt;, &lt;b&gt;sbb.ch&lt;/b&gt;&lt;br&gt;&lt;br&gt;This or prior versions uses code contribution by:&lt;br&gt;&lt;i&gt;hcm&lt;/i&gt;, &lt;i&gt;thp&lt;/i&gt;, &lt;i&gt;qwerty12&lt;/i&gt;, &lt;i&gt;qbast&lt;/i&gt;</source>
        <translation>&lt;br&gt;&lt;br&gt;Aktuell unterstützte Datenquellen:&lt;br&gt;&lt;b&gt;bahn.de&lt;/b&gt;, &lt;b&gt;mvv-muenchen.de&lt;/b&gt;, &lt;b&gt;sbb.ch&lt;/b&gt;&lt;br&gt;&lt;br&gt;Diese oder frühere Versionen enthalten code gesponsort von:&lt;br&gt;&lt;i&gt;hcm&lt;/i&gt;, &lt;i&gt;thp&lt;/i&gt;, &lt;i&gt;qwerty12&lt;/i&gt;, &lt;i&gt;qbast&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="445"/>
        <source>About Fahrplan</source>
        <translation>Über Fahrplan</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="472"/>
        <source>&lt;br&gt;Details already loading, please wait.&lt;br&gt;</source>
        <translation>&lt;br&gt;Details werden bereits geladen, bitte warten.&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="486"/>
        <source>&lt;br&gt;Error opening the details.&lt;br&gt;</source>
        <translation>&lt;br&gt;Beim öffnen der Details ist ein Fehler aufgetreten.&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="492"/>
        <source>Details</source>
        <translation>Details</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="501"/>
        <source>Add to calendar</source>
        <translation>In Kalender eintragen</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="583"/>
        <source>&lt;br&gt;&lt;b&gt;Duration: &lt;/b&gt;</source>
        <translation>&lt;br&gt;&lt;b&gt;Dauer: &lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="618"/>
        <source>&lt;br&gt;No results found.&lt;br&gt;</source>
        <translation>&lt;br&gt;Keine Ergebnisse gefunden.&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="637"/>
        <source>Results</source>
        <translation>Ergebnis</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="654"/>
        <source>to</source>
        <translation>nach</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="665"/>
        <source>Earlier</source>
        <translation>Früher</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="671"/>
        <source>Later</source>
        <translation>Später</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="684"/>
        <source> transfer</source>
        <translation> umstieg</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="687"/>
        <source> transfers</source>
        <translation> umstiege</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="706"/>
        <source>&lt;br&gt;OnTime</source>
        <translation>&lt;br&gt;Pünktlich</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="844"/>
        <source>&lt;br&gt;Please select a from and to station and make sure they are not the same.&lt;br&gt;</source>
        <translation>&lt;br&gt;Bitte zwei verschiedene Haltestellen wählen.&lt;br&gt;</translation>
    </message>
</context>
<context>
    <name>configDialog</name>
    <message>
        <location filename="configdialog.cpp" line="28"/>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="configdialog.cpp" line="36"/>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="configdialog.cpp" line="42"/>
        <source>Store last searched stations</source>
        <translation>zuletzt verwendete Haltestellen speichern</translation>
    </message>
    <message>
        <location filename="configdialog.cpp" line="48"/>
        <source>Prefill last searched station</source>
        <translation>letzte Haltestellen automatisch füllen</translation>
    </message>
    <message>
        <location filename="configdialog.cpp" line="54"/>
        <source>Launch GPS on startup</source>
        <translation>GPS automatisch starten</translation>
    </message>
    <message>
        <location filename="configdialog.cpp" line="59"/>
        <source>Use OpenStreetMap as fallback for GPS</source>
        <translation>OpenStreetMap als Sicherheit nutzen (GPS)</translation>
    </message>
    <message>
        <location filename="configdialog.cpp" line="64"/>
        <source>bahn.de</source>
        <translation>bahn.de</translation>
    </message>
    <message>
        <location filename="configdialog.cpp" line="68"/>
        <source>mvv-muenchen.de</source>
        <translation>mvv-muenchen.de</translation>
    </message>
    <message>
        <location filename="configdialog.cpp" line="72"/>
        <source>sbb.ch</source>
        <translation>sbb.ch</translation>
    </message>
    <message>
        <location filename="configdialog.cpp" line="76"/>
        <source>Databackend</source>
        <translation>Datenquelle</translation>
    </message>
</context>
<context>
    <name>parserMobileBahnDe</name>
    <message>
        <location filename="parser_mobilebahnde.cpp" line="162"/>
        <source>All</source>
        <translation>Alle</translation>
    </message>
    <message>
        <location filename="parser_mobilebahnde.cpp" line="163"/>
        <source>All without ICE</source>
        <translation>Alle ohne ICE</translation>
    </message>
    <message>
        <location filename="parser_mobilebahnde.cpp" line="164"/>
        <source>Only local transport</source>
        <translation>Nur Nahverkehr</translation>
    </message>
</context>
<context>
    <name>parserMvvDe</name>
    <message>
        <location filename="parser_mvvde.cpp" line="313"/>
        <source>Walk</source>
        <translation>Laufen</translation>
    </message>
    <message>
        <location filename="parser_mvvde.cpp" line="314"/>
        <source>S-Bahn</source>
        <translation>S-Bahn</translation>
    </message>
    <message>
        <location filename="parser_mvvde.cpp" line="315"/>
        <source>U-Bahn</source>
        <translation>U-Bahn</translation>
    </message>
    <message>
        <location filename="parser_mvvde.cpp" line="316"/>
        <source>Tram</source>
        <translation>Tram</translation>
    </message>
</context>
<context>
    <name>selectStationDialog</name>
    <message>
        <location filename="selectstationdialog.cpp" line="25"/>
        <source>City Stationname</source>
        <translation>Stadt Haltestellenname</translation>
    </message>
    <message>
        <location filename="selectstationdialog.cpp" line="50"/>
        <source>GPS</source>
        <translation>GPS</translation>
    </message>
    <message>
        <location filename="selectstationdialog.cpp" line="51"/>
        <source>Search</source>
        <translation>Suchen</translation>
    </message>
    <message>
        <location filename="selectstationdialog.cpp" line="122"/>
        <source>Select a station</source>
        <translation>Haltestelle wählen</translation>
    </message>
</context>
</TS>

==> fahrplan_0.0.17.tar.gz: fahrplan-0.0.17/fahrplan_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.cpp" line="31"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="36"/>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="41"/>
        <source>Toggle GPS</source>
        <translation>GPS An/Aus</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="46"/>
        <location filename="mainwindow.cpp" line="313"/>
        <source>Donate</source>
        <translation>Spenden</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="62"/>
        <source>Station from</source>
        <translation>Haltestelle ab</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="63"/>
        <source>Station to</source>
        <translation>Haltestelle bis</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="66"/>
        <location filename="mainwindow.cpp" line="68"/>
        <location filename="mainwindow.cpp" line="690"/>
        <source>please select</source>
        <translation>bitte wählen</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="92"/>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="96"/>
        <source>Time</source>
        <translation>Uhrzeit</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="190"/>
        <source>- bahn.de: fixed crash problem&lt;br&gt;- optimized calendar selection screen&lt;br&gt;- arrival/departue selector changed to toggle button.</source>
        <translation>- bahn.de: absturz problem behoben&lt;br&gt;- kalender auswahl verbessert&lt;br&gt;- abfahrt/ankuft knopf verbessert</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="286"/>
        <source>Arrival time</source>
        <translation>Ankunft</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="112"/>
        <location filename="mainwindow.cpp" line="282"/>
        <source>Departure time</source>
        <translation>Abfahrt</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="110"/>
        <source>Use selected date/time as</source>
        <translation>Datum und Zeit verwenden als</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="119"/>
        <source>Restrict train types</source>
        <translation>Verkehrsmittel</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="130"/>
        <source>Search</source>
        <translation>Suchen</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="189"/>
        <source>Welcome to a new version of fahrplan this has changed</source>
        <translation>Willkommen bei einer neuen Version von Fahrplan, dies ist neu</translation>
    </message>
    <message>
        <source>- bahn.de: adding train restrictions&lt;br&gt;- Calendar: you can select to which calendar you want add the journey.&lt;br&gt;- last used stationnames could be filled automatically on startup.&lt;br&gt;- Added a Donate link to the mainmenu</source>
        <translation type="obsolete">- bahn.de: filtern nach Verkehrsmittel&lt;br&gt;-Kalender: Man kann nun wählen zu welchem Kalender man die Verbindung hinzufügen möchte&lt;br&gt;-letzte Haltestelle kann automatisch gefüllt werden&lt;br&gt;Es gibt nun einen Spenden knopf</translation>
    </message>
    <message>
        <source>- bahn.de: fixed gps search&lt;br&gt;- making sure the Birthdays calendar will not be displayed as a valid target calendar.</source>
        <translation type="obsolete">-bahn.de: fehler mit gps suche behoben&lt;br&gt;- Geburtstags Kalender wird nun nicht mehr als wählbarer kalender angezeigt.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="224"/>
        <source>not supported</source>
        <translation>nicht unterstützt</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="248"/>
        <source>&lt;br&gt;GPS is now available!&lt;br&gt;</source>
        <translation>&lt;br&gt;GPS ist nun verfügbar!&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="259"/>
        <source>&lt;br&gt;GPS is now &lt;b&gt;disabled&lt;/b&gt;&lt;br&gt;</source>
        <translation>&lt;br&gt;GPS ist jetzt &lt;b&gt;aus&lt;/b&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="264"/>
        <source>&lt;br&gt;GPS is now &lt;b&gt;enabled&lt;/b&gt;&lt;br&gt;</source>
        <translation>&lt;br&gt;GPS ist jetzt &lt;b&gt;an&lt;/b&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>Journey: </source>
        <translation type="obsolete">Verbindung: </translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="455"/>
        <source> to </source>
        <translation> nach </translation>
    </message>
    <message>
        <source>Duration: </source>
        <translation type="obsolete">Dauer: </translation>
    </message>
    <message>
        <source>

(added by fahrplan app, please recheck informations before travel.)</source>
        <translatorcomment>dont use umlauts!</translatorcomment>
        <translation type="obsolete">

(hinzugefuegt von Fahrplan, bitte vor Fahrantritt daten erneut pruefen)</translation>
    </message>
    <message>
        <source>&lt;br&gt;Entry is in the past!&lt;br&gt;</source>
        <translation type="obsolete">&lt;br&gt;Eintrag ist in der Vergangenheit!&lt;br&gt;</translation>
    </message>
    <message>
        <source>&lt;br&gt;Entry added to the </source>
        <translation type="obsolete">&lt;br&gt;Eintrag wurde zum </translation>
    </message>
    <message>
        <source> calendar.&lt;br&gt;</source>
        <translation type="obsolete"> Kalender hinzugefügt.&lt;br&gt;</translation>
    </message>
    <message>
        <source>Select target calendar</source>
        <translation type="obsolete">Ziel Kalender wählen</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="314"/>
        <source>Thank you for Donating!</source>
        <translation>Danke fürs spenden!</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="320"/>
        <source>by smurfy (maemo@smurfy.de)&lt;br&gt;Version </source>
        <translation>von smurfy (maemo@smurfy.de)&lt;br&gt;Version </translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="320"/>
        <source>&lt;br&gt;&lt;br&gt;Current supported databackends:&lt;br&gt;&lt;b&gt;bahn.de&lt;/b&gt;, &lt;b&gt;mvv-muenchen.de&lt;/b&gt;, &lt;b&gt;sbb.ch&lt;/b&gt;&lt;br&gt;&lt;br&gt;This or prior versions uses code contribution by:&lt;br&gt;&lt;i&gt;hcm&lt;/i&gt;, &lt;i&gt;thp&lt;/i&gt;, &lt;i&gt;qwerty12&lt;/i&gt;, &lt;i&gt;qbast&lt;/i&gt;</source>
        <translation>&lt;br&gt;&lt;br&gt;Aktuell unterstützte Datenquellen:&lt;br&gt;&lt;b&gt;bahn.de&lt;/b&gt;, &lt;b&gt;mvv-muenchen.de&lt;/b&gt;, &lt;b&gt;sbb.ch&lt;/b&gt;&lt;br&gt;&lt;br&gt;Diese oder frühere Versionen enthalten code gesponsort von:&lt;br&gt;&lt;i&gt;hcm&lt;/i&gt;, &lt;i&gt;thp&lt;/i&gt;, &lt;i&gt;qwerty12&lt;/i&gt;, &lt;i&gt;qbast&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="322"/>
        <source>About Fahrplan</source>
        <translation>Über Fahrplan</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="349"/>
        <source>&lt;br&gt;Details already loading, please wait.&lt;br&gt;</source>
        <translation>&lt;br&gt;Details werden bereits geladen, bitte warten.&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="363"/>
        <source>&lt;br&gt;Error opening the details.&lt;br&gt;</source>
        <translation>&lt;br&gt;Beim öffnen der Details ist ein Fehler aufgetreten.&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="369"/>
        <source>Details</source>
        <translation>Details</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="378"/>
        <source>Add to calendar</source>
        <translation>In Kalender eintragen</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="460"/>
        <source>&lt;br&gt;&lt;b&gt;Duration: &lt;/b&gt;</source>
        <translation>&lt;br&gt;&lt;b&gt;Dauer: &lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="495"/>
        <source>&lt;br&gt;No results found.&lt;br&gt;</source>
        <translation>&lt;br&gt;Keine Ergebnisse gefunden.&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="514"/>
        <source>Results</source>
        <translation>Ergebnis</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="531"/>
        <source>to</source>
        <translation>nach</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="542"/>
        <source>Earlier</source>
        <translation>Früher</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="548"/>
        <source>Later</source>
        <translation>Später</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="561"/>
        <source> transfer</source>
        <translation> umstieg</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="564"/>
        <source> transfers</source>
        <translation> umstiege</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="583"/>
        <source>&lt;br&gt;OnTime</source>
        <translation>&lt;br&gt;Pünktlich</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="720"/>
        <source>&lt;br&gt;Please select a from and to station and make sure they are not the same.&lt;br&gt;</source>
        <translation>&lt;br&gt;Bitte zwei verschiedene Haltestellen wählen.&lt;br&gt;</translation>
    </message>
</context>
<context>
    <name>calendarDialog</name>
    <message>
        <location filename="calendardialog.cpp" line="29"/>
        <source>Select target calendar</source>
        <translation>Ziel Kalender wählen</translation>
    </message>
    <message>
        <location filename="calendardialog.cpp" line="157"/>
        <source>Private</source>
        <translation>Privat</translation>
    </message>
    <message>
        <location filename="calendardialog.cpp" line="173"/>
        <source>Journey: </source>
        <translation>Verbindung: </translation>
    </message>
    <message>
        <location filename="calendardialog.cpp" line="173"/>
        <location filename="calendardialog.cpp" line="174"/>
        <source> to </source>
        <translation> nach </translation>
    </message>
    <message>
        <location filename="calendardialog.cpp" line="182"/>
        <source>Duration: </source>
        <translation>Dauer: </translation>
    </message>
    <message>
        <location filename="calendardialog.cpp" line="219"/>
        <source>

(added by fahrplan app, please recheck informations before travel.)</source>
        <translation>

(hinzugefuegt von Fahrplan, bitte vor Fahrantritt daten erneut pruefen)</translation>
    </message>
    <message>
        <location filename="calendardialog.cpp" line="98"/>
        <location filename="calendardialog.cpp" line="229"/>
        <source>&lt;br&gt;Entry is in the past!&lt;br&gt;</source>
        <translation>&lt;br&gt;Eintrag ist in der Vergangenheit!&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="calendardialog.cpp" line="244"/>
        <source>&lt;br&gt;Entry added to the </source>
        <translation>&lt;br&gt;Eintrag wurde zum </translation>
    </message>
    <message>
        <location filename="calendardialog.cpp" line="244"/>
        <source> calendar.&lt;br&gt;</source>
        <translation> Kalender hinzugefügt.&lt;br&gt;</translation>
    </message>
</context>
<context>
    <name>configDialog</name>
    <message>
        <location filename="configdialog.cpp" line="28"/>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="configdialog.cpp" line="33"/>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="configdialog.cpp" line="39"/>
        <source>Store last searched stations</source>
        <translation>zuletzt verwendete Haltestellen speichern</translation>
    </message>
    <message>
        <location filename="configdialog.cpp" line="45"/>
        <source>Prefill last searched station</source>
        <translation>letzte Haltestellen automatisch füllen</translation>
    </message>
    <message>
        <location filename="configdialog.cpp" line="51"/>
        <source>Launch GPS on startup</source>
        <translation>GPS automatisch starten</translation>
    </message>
    <message>
        <location filename="configdialog.cpp" line="56"/>
        <source>Use OpenStreetMap as fallback for GPS</source>
        <translation>OpenStreetMap als Sicherheit nutzen (GPS)</translation>
    </message>
    <message>
        <location filename="configdialog.cpp" line="61"/>
        <source>bahn.de</source>
        <translation>bahn.de</translation>
    </message>
    <message>
        <location filename="configdialog.cpp" line="65"/>
        <source>mvv-muenchen.de</source>
        <translation>mvv-muenchen.de</translation>
    </message>
    <message>
        <location filename="configdialog.cpp" line="69"/>
        <source>sbb.ch</source>
        <translation>sbb.ch</translation>
    </message>
    <message>
        <location filename="configdialog.cpp" line="73"/>
        <source>Databackend</source>
        <translation>Datenquelle</translation>
    </message>
</context>
<context>
    <name>parserMobileBahnDe</name>
    <message>
        <location filename="parser_mobilebahnde.cpp" line="163"/>
        <source>All</source>
        <translation>Alle</translation>
    </message>
    <message>
        <location filename="parser_mobilebahnde.cpp" line="164"/>
        <source>All without ICE</source>
        <translation>Alle ohne ICE</translation>
    </message>
    <message>
        <location filename="parser_mobilebahnde.cpp" line="165"/>
        <source>Only local transport</source>
        <translation>Nur Nahverkehr</translation>
    </message>
</context>
<context>
    <name>parserMvvDe</name>
    <message>
        <location filename="parser_mvvde.cpp" line="313"/>
        <source>Walk</source>
        <translation>Laufen</translation>
    </message>
    <message>
        <location filename="parser_mvvde.cpp" line="314"/>
        <source>S-Bahn</source>
        <translation>S-Bahn</translation>
    </message>
    <message>
        <location filename="parser_mvvde.cpp" line="315"/>
        <source>U-Bahn</source>
        <translation>U-Bahn</translation>
    </message>
    <message>
        <location filename="parser_mvvde.cpp" line="316"/>
        <source>Tram</source>
        <translation>Tram</translation>
    </message>
</context>
<context>
    <name>selectStationDialog</name>
    <message>
        <location filename="selectstationdialog.cpp" line="25"/>
        <source>City Stationname</source>
        <translation>Stadt Haltestellenname</translation>
    </message>
    <message>
        <location filename="selectstationdialog.cpp" line="50"/>
        <source>GPS</source>
        <translation>GPS</translation>
    </message>
    <message>
        <location filename="selectstationdialog.cpp" line="51"/>
        <source>Search</source>
        <translation>Suchen</translation>
    </message>
    <message>
        <location filename="selectstationdialog.cpp" line="122"/>
        <source>Select a station</source>
        <translation>Haltestelle wählen</translation>
    </message>
</context>
</TS>
